@@ -181,7 +181,7 @@ def load_library():
     libsteps.api_bus_number2bus_name.restype = c_char_p
     libsteps.api_bus_number2bus_name.argtypes = (c_uint, c_uint)
     libsteps.api_bus_name2bus_number.restype = c_uint
-    libsteps.api_bus_name2bus_number.argtypes = (c_char_p, c_uint)
+    libsteps.api_bus_name2bus_number.argtypes = (c_char_p, c_double, c_uint)
 
     libsteps.api_initialize_bus_search.restype = None
     libsteps.api_initialize_bus_search.argtypes = (c_double, c_double, c_double, c_double, c_uint, c_uint, c_uint, c_uint)
@@ -560,7 +560,7 @@ def load_library():
     libsteps.api_build_network_Z_matrix.restype = None
     libsteps.api_build_network_Z_matrix.argtypes = (c_uint, )
     libsteps.api_save_network_Y_matrix.restype = None
-    libsteps.api_save_network_Y_matrix.argtypes = (c_char_p, c_uint)
+    libsteps.api_save_network_Y_matrix.argtypes = (c_char_p, c_bool, c_uint)
     libsteps.api_save_decoupled_network_B_matrix.restype = None
     libsteps.api_save_decoupled_network_B_matrix.argtypes = (c_char_p, c_uint)
     libsteps.api_save_dc_network_B_matrix.restype = None
@@ -659,6 +659,11 @@ def load_library():
     libsteps.api_get_system_angular_stable_flag.restype = c_bool
     libsteps.api_get_system_angular_stable_flag.argtypes = (c_uint, )
 
+    libsteps.api_get_user_meter_value.restype = c_double
+    libsteps.api_get_user_meter_value.argtypes = (c_uint, c_uint)
+    libsteps.api_get_basic_meter_value.restype = c_double
+    libsteps.api_get_basic_meter_value.argtypes = (c_char_p, c_uint)
+
     libsteps.api_set_bus_fault.restype = None
     libsteps.api_set_bus_fault.argtypes = (c_uint, c_char_p, c_double, c_double, c_uint)
     libsteps.api_clear_bus_fault.restype = None
